@@ -41,7 +41,7 @@ def list_all_file(access_token: str, dir_path: str, recursion: int = 0,
                                web=web, api_instance=api_instance)
     if _result and _result.file_list:
         tmp_file_list.extend(_result.file_list)
-        while (_result.errno == 0 or _result.errno is None) and _result.has_more:
+        while _result and (_result.errno == 0 or _result.errno is None) and _result.has_more:
             _result = list_all_by_page(access_token, dir_path=dir_path, recursion=recursion, order=order, desc=desc,
                                        start=_result.cursor, web=web, api_instance=api_instance)
             if _result and _result.file_list:
