@@ -4,6 +4,11 @@
 from datetime import datetime
 import time
 
+one_minute_seconds = 60
+one_hour_seconds = 60 * one_minute_seconds
+one_day_seconds = one_hour_seconds * 24
+one_week_seconds = one_day_seconds * 7
+
 
 def get_today(time_formate: str = '%Y%m%d'):
     """获取当日的日期字符串"""
@@ -20,6 +25,11 @@ def get_timestamp() -> int:
     return int(time.time())
 
 
+def get_time_str(time_formate: str = '%Y%m%d%H%M%S%f') -> str:
+    """获取时间字符串"""
+    return datetime.now().strftime(time_formate)
+
+
 def get_now_info():
     """获取现在的信息"""
     now_time = datetime.now()
