@@ -14,5 +14,5 @@ class BaseService:
                 self.po_service = self.po_service_type(db_code=self.db_code, model_type=self.po_model_type)
             else:
                 self.po_service = self.po_service_type(db_code=self.db_code)
-            if self.po_model_type is None:
+            if not hasattr(self, 'po_model_type') or self.po_model_type is None:
                 self.po_model_type = self.po_service.model_type
