@@ -18,5 +18,8 @@ class LinkService(BaseService):
             code=f'{tmp.type_code}|{tmp.code}',
             title=tmp.title,
             description=tmp.description,
-            image=icon_base_service.get_icon_code(tmp.icon_type, tmp.icon_value, tmp.title),
+            image=icon_base_service.get_icon_code(icon_type=tmp.icon_type,
+                                                  icon_value=tmp.icon_value,
+                                                  alt=tmp.title,
+                                                  image_src=tmp.image_src),
         ) for tmp in data_list] if data_list else []
