@@ -1,11 +1,8 @@
 import os.path
 
-from afeng_tools.web_tool import request_tools
-
-from afeng_tools.encryption_tool import hashlib_tools
+from starlette.requests import Request
 from starlette.responses import Response
 from starlette.templating import Jinja2Templates, _TemplateResponse
-from starlette.requests import Request
 
 from afeng_tools.application_tool import settings_tools
 from afeng_tools.application_tool.settings_enum import SettingsKeyEnum
@@ -14,26 +11,6 @@ from afeng_tools.file_tool import tmp_file_tools
 jinja2_templates = Jinja2Templates(directory=settings_tools.get_config(SettingsKeyEnum.server_template_path))
 
 
-def generate_unique_id(request: Request):
-    return hashlib_tools.calc_unique_id(data_list=[
-        request_tools.is_mobile(request.headers.get('user-agent')),
-        request.method,
-        request.url,
-        request.query_params,
-    ], split_chat='||')
-
-
-def generate_request_cache_name(request: Request, cache_path: str):
-    """
-    生成request缓存
-    :param request: request请求
-    :param cache_path: 缓存路径
-    :return:
-    """
-    unique_id = generate_unique_id(request)
-    return os.path.join(cache_path, unique_id)
-
-
 def create_template_response(request: Request, template_file: str, context: dict = None, is_cache=False,
                              cache_path: str = tmp_file_tools.get_user_tmp_dir()) -> _TemplateResponse:
     """
